@@ -1,11 +1,8 @@
 import os
 from jinja2 import Template
 
-from ww import f
-
-
 class Tpl:
-    def __init__(self, template_dir):
+    def __init__(self, logger, template_dir):
         self.files = {}
 
         self.expected_files = [
@@ -15,10 +12,13 @@ class Tpl:
             "can_ids_c.jinja",
             "common_c.jinja",
             "common_h.jinja",
+            "enums_h.jinja"
         ]
 
         self.template_dir = template_dir
         self.tpl = {}
+
+        self.logger = logger
         return
 
     def check_tpl_dir(self):
@@ -26,7 +26,7 @@ class Tpl:
 
         for k in self.expected_files:
             if k not in files:
-                return False, f("{k} missing")
+                return False, f"{k} missing"
 
         return True, ""
 
@@ -38,10 +38,21 @@ class Tpl:
             expand_files[k] = os.path.join(self.template_dir, k)
 
         return expand_files
+    
+    def render(self, name, *args, **kwargs):
+        template = self.tpl.get(name)
+        if template == None:
+            self.logger.error(f"Error: Template not found, {name}")
+            return ""
+
+        return template.render(**kwargs)
 
     def open_tpl_files(self):
         self.files = self._get_tpl_dir_files()
 
         for k, v in self.files.items():
-            with open(v) as f:
-                self.tpl[k] = Template(f.read())
+            try:
+                with open(v) as f:
+                    self.tpl[k] = Template(f.read())
+            except Exception as e:
+                self.logger.error(f"Error opening template: {v} not found",  e)
